#
# spec file for package python-readthedocs-sphinx-ext
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-readthedocs-sphinx-ext
VCS: https://src.suse.de/SLFO-pool/python-readthedocs-sphinx-ext#9e5d04ffce824f2b4db8b71efab6f6b858cfc601b45045f1a0c2d49d32c5514e
Version:        2.2.5
Release:        160000.1.9
Summary:        Sphinx extension for Read the Docs overrides
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/rtfd/readthedocs-sphinx-ext
Source:         https://files.pythonhosted.org/packages/source/r/readthedocs-sphinx-ext/readthedocs-sphinx-ext-%{version}.tar.gz
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Sphinx
Requires:       python-requests
BuildArch:      noarch
%python_subpackages

%description
This module adds extensions that make Sphinx easier to use.
Some of them require Read the Docs features,
others are just code that we ship and enable during builds on Read the Docs.

%prep
%setup -q -n readthedocs-sphinx-ext-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/readthedocs_ext
%{python_sitelib}/readthedocs_sphinx_ext-%{version}.dist-info

%changelog
* Sun Jun 30 2024 dmueller@suse.com
- build as PEP517
* Fri Dec 29 2023 dmueller@suse.com
- update to 2.2.5:
  * Revert "Keep default Search.init behavior if addons injected
* Fri Dec 15 2023 dmueller@suse.com
- update to 2.2.4:
  * Reduce loglevel to info
  * Keep default Search.init behavior if addons injected
* Thu Sep  7 2023 dmueller@suse.com
- update to 2.2.2:
  * Remove build-time and commit field to avoid changing all pages
  * Stop creating readthedocs-sphinx-domain-names.json
* Fri Apr 21 2023 dmueller@suse.com
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 mcepl@suse.com
- Make calling of %%{sle15modernpython} optional.
* Sat Oct 29 2022 yarunachalam@suse.com
- Update to version 2.2.0
  Telemetry: dump `app.extensions` and `app.config.html_theme` (#117)
  * Telemetry: dump `app.extensions` and `app.config.html_theme`
    Dump data from Sphinx into a JSON file that will be read and processed by our
    Telemetry collector. This will help us to get some insights about extensions and
    theme usage.
  * Telemetry: handle unexpected exceptions
  * Telemetry: comment about config-inited
  * Style
  * Telemetry: save only extensions defined by the user
    Instead of saving `app.extensions` (all extensions used by Sphinx, including
    default ones), we only save `app.config.extensions` which are the ones defined
    by the user itself.
    Update release steps (#116)
    Use build is recommend now
    https://packaging.python.org/en/latest/guides/distributing-packages-using-setuptools/#packaging-your-project
* Wed Oct 12 2022 yarunachalam@suse.com
- Update to version 2.1.9
  * fix: Only add external version warning nodes on documents (#114)
* Sat Jun  4 2022 arun@gmx.de
- update to version 2.1.8:
  * Remove direct call to distutils in favor of more modern packaging
- changes from version 2.1.7:
  * Use proxied_static_path if available
- changes from version 2.1.6:
  * External version warning: avoid using the deprecated traverse
    method
  * Update tox.ini to reflect the current package state
  * Update some deps
* Fri Mar 18 2022 arun@gmx.de
- update to version 2.1.5:
  * Search: correctly remove Search.init on Sphinx >= 5.0
* Sat Jan 29 2022 arun@gmx.de
- specfile:
  * update copyright year
- update to version 2.1.4:
  * Update canonical_url to properly respect builder
- changes from version 2.1.3:
  * Use circleci
- changes from version 2.1.2:
  * Canonical URL: don't set it if is empty
* Sat Jul 25 2020 arun@gmx.de
- update to version 2.1.1:
  * New line at the end of the file
  * Put the JS embed back into script_files (#92)
* Sat Jul 11 2020 arun@gmx.de
- update to version 2.1.0:
  * Merge pull request #90 from readthedocs/humitos/parallel-read-safe
- changes from version 2.0.0:
  * Define parallel_read_safe=True for our extensions
  * Move the feature flags added in #85
  * Re-add the builders as deprecated
  * Use Py3 for Lint
  * Remove the custom RTD builders
* Sat May 30 2020 arun@gmx.de
- update to version 1.0.4:
  * Re-add proxied_api_host to allow overriding it
* Fri Apr 24 2020 arun@gmx.de
- specfile:
  * no more need to remove tests manually before install
- update to version 1.0.3:
  * Fix path to html_context
- changes from version 1.0.2:
  * Add Python 3.8 to tests
  * Add more versions to test against
  * Revert #77
  * Make setup.py executable
  * Stop installing tests
  * Remove broken distutils compat
* Sat Jan 18 2020 arun@gmx.de
- specfile:
  * update copyright year
  * be more specific in %%files section
- update to version 1.0.1:
  * more JS exscapes
  * Use new footer_api_host settings
  * rename setting
* Mon Jul 22 2019 tchvatal@suse.com
- Update to 1.0:
  * no upstream changelog
* Fri May 24 2019 tchvatal@suse.com
- Initial commit, needed by rdt_theme
